@@ -1,6 +1,7 @@
 """
 Module for checking a latex document by applying a set of checker and filter.
 """
+import logging
 import typing
 
 from checkmytex.filtering.filter import Filter
@@ -26,7 +27,7 @@ class DocumentAnalyzer:
     Simple class to return the files and its problems of a latex document.
     """
 
-    def __init__(self, log=print):
+    def __init__(self, log: object = print) -> object:
         self.log = log
         self.checker = []
         self.rules = []
@@ -49,8 +50,6 @@ class DocumentAnalyzer:
         self.add_checker(Proselint())
         self.add_checker(Cleveref())
         self.add_checker(UniformNpHard())
-        for checker in self.checker:
-            checker.log = self.log
 
     def add_checker(self, checker: Checker) -> None:
         """
@@ -96,5 +95,12 @@ class DocumentAnalyzer:
 
     def _find_problems(self, latex_document: LatexDocument) -> typing.Iterable[Problem]:
         for checker in self.checker:
-            for problem in checker.check(latex_document):
-                yield problem
+            try:
+                for problem in checker.check(latex_document):
+                    yield problem
+            except AssertionError as ae:
+                raise ae
+            except Exception as e:
+                logging.getLogger("CheckMyTex").error(
+                    f"Exception using {checker}: {e}."
+                )
