@@ -15,6 +15,10 @@ from .problem import Problem
 
 
 class AspellChecker(Checker):
+    def __init__(self, lang="en_US"):
+        super().__init__()
+        self.lang = lang
+
     def _get_words(
         self, document: LatexDocument
     ) -> typing.Dict[str, typing.List[Origin]]:
@@ -29,7 +33,7 @@ class AspellChecker(Checker):
             if not is_word.fullmatch(word):
                 continue
             begin = match.start("word")
-            origin = document.get_origin_of_text(begin, begin + len(word))
+            origin = document.get_simplified_origin_of_text(begin, begin + len(word))
             if word not in word_occurrences:
                 word_occurrences[word] = []
             word_occurrences[word].append(origin)
@@ -40,7 +44,7 @@ class AspellChecker(Checker):
         words = self._get_words(document)
         bin = shutil.which("aspell")
         word_list = "\n".join(words.keys())
-        out, err, code = self._run(f"{bin}  -a --lang=en_US", input=word_list)
+        out, err, code = self._run(f"{bin}  -a --lang={self.lang}", input=word_list)
         regex = re.compile(r"^\s*&\s*(?P<word>\w+)[0-9\s]*:(?P<sugg>.*)$", re.MULTILINE)
         for match in regex.finditer(out):
             word = match.group("word").strip()
@@ -73,17 +77,18 @@ class AspellChecker(Checker):
             return False
         out, err, code = self._run(f"{bin_path} dicts")
         if code:  # something happened.
-            print("Could not query aspell dicts:", err)
+            self.log("Could not query aspell dicts:", err)
             return False
-        if "en_US" in out.split("\n"):
+        if self.lang in out.split("\n"):
             return True
+        self.log(f"Could not find aspell dictionary for {self.lang}.")
         return False
 
 
 class CheckSpell(Checker):
-    def __init__(self):
+    def __init__(self, lang="en"):
         super().__init__()
-        self.spell = SpellChecker(distance=1)
+        self.spell = SpellChecker(distance=1, language=lang)
         # self._word_finder = re.compile(r"")
 
     def check(self, document: LatexDocument) -> typing.Iterable[Problem]:
@@ -107,7 +112,7 @@ class CheckSpell(Checker):
         for word_element in word_elements:
             if len(word_element) < 2 or not self.spell.unknown([word_element]):
                 continue
-            origin = document.get_origin_of_text(begin, begin + len(word))
+            origin = document.get_simplified_origin_of_text(begin, begin + len(word))
             candidates = [
                 c for c in self.spell.candidates(word_element) if c != word_element
             ]
